## Installation

<br />

Since lowbar is an extremely small module contained in a single file, installing it system-wide as a pip module is unnecessary. You can download and add lowbar to your project's code directly:
```
wget -O lowbar.py https://raw.githubusercontent.com/AnnikaV9/lowbar/master/src/lowbar/__init__.py
```

<br />

If you do wish to install it as a system-wide module:
```
git clone https://github.com/AnnikaV9/lowbar.git
cd lowbar
python3 -m pip install build hatchling
python3 -m build -w
python3 -m pip install dist/lowbar-*-py3-none-any.whl
```
*You can also download the wheel from the [releases](https://github.com/AnnikaV9/lowbar/releases/) page.*

<div align="center">

<br />
<br />

<div align="center">
<a href="https://github.com/AnnikaV9/lowbar">Home</a> &nbsp; | &nbsp;
<a href="DOCUMENTATION.md">Documentation</a> &nbsp; | &nbsp;
<a href="LICENSE">License</a>
</div>
